@@ -1,3 +1,4 @@
+from elasticsearch import AsyncElasticsearch
 from guillotina import directives
 from guillotina.catalog.catalog import DefaultCatalogDataAdapter
 from guillotina.component import get_adapter
@@ -20,17 +21,11 @@ from guillotina.utils import get_content_path
 from guillotina.utils import get_current_container
 from guillotina.utils import get_current_transaction
 from guillotina.utils import get_security_policy
-from guillotina_elasticsearch import ELASTIC6
 from guillotina_elasticsearch.events import IndexProgress
-from guillotina_elasticsearch.interfaces import DOC_TYPE
-from guillotina_elasticsearch.interfaces import IIndexActive
 from guillotina_elasticsearch.interfaces import IIndexManager
-from guillotina_elasticsearch.utils import find_index_manager
 from guillotina_elasticsearch.utils import get_migration_lock
 from guillotina_elasticsearch.utils import noop_response
-from os.path import join
 
-import aioelasticsearch
 import asyncio
 import backoff
 import elasticsearch.exceptions
@@ -148,7 +143,6 @@ class Migrator:
         mapping_only=False,
         index_manager=None,
         children_only=False,
-        lookup_index=False,
         cache=True,
     ):
         self.utility = utility
@@ -161,7 +155,6 @@ class Migrator:
         self.bulk_size = bulk_size
         self.reindex_security = reindex_security
         self.children_only = children_only
-        self.lookup_index = lookup_index
         if mapping_only and full:
             raise Exception("Can not do a full reindex and a mapping only migration")
         self.mapping_only = mapping_only
@@ -173,7 +166,7 @@ class Migrator:
 
         self.request = request
         self.container = get_current_container()
-        self.conn = utility.get_connection()
+        self.conn: AsyncElasticsearch = utility.get_connection()
 
         if index_manager is None:
             self.index_manager = get_adapter(self.container, IIndexManager)
@@ -200,7 +193,6 @@ class Migrator:
         self.copied_docs = 0
 
         self.work_index_name = None
-        self.sub_indexes = []
 
     def per_sec(self):
         return self.processed / (time.time() - self.index_start_time)
@@ -209,66 +201,56 @@ class Migrator:
         async with transaction(adopt_parent_txn=True) as txn:
             await txn.refresh(await self.index_manager.get_registry())
             next_index_name = await self.index_manager.start_migration()
-        if await self.conn.indices.exists(next_index_name):
-            if self.force:
-                # delete and recreate
-                self.response.write("Clearing index")
-                resp = await self.conn.indices.delete(next_index_name)
-                assert resp["acknowledged"]
-        await self.utility.create_index(next_index_name, self.index_manager)
+            # The index is created in the same transaction the registry is updated
+            # to prevent another process from accessing the 'next_index' and not finding it
+            if await self.conn.indices.exists(next_index_name):
+                if self.force:
+                    # delete and recreate
+                    self.response.write("Clearing index")
+                    resp = await self.conn.indices.delete(next_index_name)
+                    assert resp["acknowledged"]
+            await self.utility.create_index(next_index_name, self.index_manager)
         return next_index_name
 
     async def copy_to_next_index(self):
-        conn_es = await self.conn.transport.get_connection()
         real_index_name = await self.index_manager.get_index_name()
-        async with conn_es.session.post(
-            join(str(conn_es.base_url), "_reindex"),
+        data = await self.conn.reindex(
+            {
+                "source": {"index": real_index_name, "size": 100},
+                "dest": {"index": self.work_index_name},
+            },
             params={"wait_for_completion": "false"},
-            headers={"Content-Type": "application/json"},
-            data=json.dumps(
-                {
-                    "source": {"index": real_index_name, "size": 100},
-                    "dest": {"index": self.work_index_name},
-                }
-            ),
-        ) as resp:
-            data = await resp.json()
-            self.active_task_id = task_id = data["task"]
-            task_completed = False
-            while not task_completed:
-                await asyncio.sleep(10)
-                async with conn_es.session.get(
-                    join(str(conn_es.base_url), "_tasks", task_id),
-                    headers={"Content-Type": "application/json"},
-                ) as resp:
-                    if resp.status in (400, 404):
-                        break
-                    data = await resp.json()
-                    task_completed = data["completed"]
-                    if task_completed:
-                        break
-                    status = data["task"]["status"]
-                    self.response.write(
-                        f'{status["created"]}/{status["total"]} - '
-                        f"Copying data to new index. task id: {task_id}"
-                    )
-                    self.copied_docs = status["created"]
-
-            self.active_task_id = None
+        )
+        self.active_task_id = task_id = data["task"]
+        task_completed = False
+        while not task_completed:
+            await asyncio.sleep(10)
+            data = await self.conn.tasks.get(task_id)
+            task_completed = data["completed"]
             if task_completed:
-                response = data["response"]
-                failures = response["failures"]
-                if len(failures) > 0:
-                    failures = json.dumps(
-                        failures, sort_keys=True, indent=4, separators=(",", ": ")
-                    )
-                    self.response.write(f"Reindex encountered failures: {failures}")
-                else:
-                    self.response.write(
-                        f"Finished copying to new index: {self.copied_docs}"
-                    )
+                break
+            status = data["task"]["status"]
+            self.response.write(
+                f'{status["created"]}/{status["total"]} - '
+                f"Copying data to new index. task id: {task_id}"
+            )
+            self.copied_docs = status["created"]
+
+        self.active_task_id = None
+        if task_completed:
+            response = data["response"]
+            failures = response["failures"]
+            if len(failures) > 0:
+                failures = json.dumps(
+                    failures, sort_keys=True, indent=4, separators=(",", ": ")
+                )
+                self.response.write(f"Reindex encountered failures: {failures}")
             else:
-                self.response.write(f"Unknown state for task {task_id}")
+                self.response.write(
+                    f"Finished copying to new index: {self.copied_docs}"
+                )
+        else:
+            self.response.write(f"Unknown state for task {task_id}")
 
     async def get_all_uids(self):
         self.response.write("Retrieving existing doc ids")
@@ -301,12 +283,7 @@ class Migrator:
         Missing ones are ignored and we don't care about it.
         """
         next_mappings = await self.conn.indices.get_mapping(self.work_index_name)
-        next_mappings = next_mappings[self.work_index_name]["mappings"]
-
-        if ELASTIC6:
-            next_mappings = next_mappings[DOC_TYPE]["properties"]
-        else:
-            next_mappings = next_mappings["properties"]
+        next_mappings = next_mappings[self.work_index_name]["mappings"]["properties"]
 
         existing_index_name = await self.index_manager.get_real_index_name()
         try:
@@ -315,12 +292,9 @@ class Migrator:
             # allows us to upgrade when no index is present yet
             return next_mappings
 
-        existing_mappings = existing_mappings[existing_index_name]["mappings"]
-
-        if ELASTIC6:
-            existing_mappings = existing_mappings[DOC_TYPE]["properties"]
-        else:
-            existing_mappings = existing_mappings["properties"]
+        existing_mappings = existing_mappings[existing_index_name]["mappings"][
+            "properties"
+        ]
 
         new_definitions = {}
         for field_name, definition in next_mappings.items():
@@ -332,9 +306,10 @@ class Migrator:
         return new_definitions
 
     async def process_folder(self, ob):
+        txn = get_current_transaction()
         for key in await ob.async_keys():
             try:
-                item = await ob.__txn__.get_child(ob, key)
+                item = await txn.get_child(ob, key)
             except (KeyError, ModuleNotFoundError):
                 continue
             if item is None:
@@ -364,34 +339,31 @@ class Migrator:
         await self.index_object(ob, full=full)
         self.processed += 1
 
-        if IIndexActive.providedBy(ob):
-            self.sub_indexes.append(ob)
-        else:
-            if IFolder.providedBy(ob):
-                await self.process_folder(ob)
+        if IFolder.providedBy(ob):
+            await self.process_folder(ob)
 
-            if not IContainer.providedBy(ob):
-                try:
-                    del self.container.__gannotations__
-                except AttributeError:
-                    del self.container.__annotations__
-            del ob
+        if not IContainer.providedBy(ob):
+            try:
+                del self.container.__gannotations__
+            except AttributeError:
+                del self.container.__annotations__
+        del ob
 
     async def index_object(self, ob, full=False):
         batch_type = "update"
-        if self.reindex_security:
-            try:
-                data = await apply_coroutine(ISecurityInfo(ob))
-            except TypeError:
-                self.response.write(f"Could not index {ob}")
-                return
-        elif full or self.full:
+        if full or self.full:
             try:
                 data = await ICatalogDataAdapter(ob)()
             except TypeError:
                 self.response.write(f"Could not index {ob}")
                 return
             batch_type = "index"
+        elif self.reindex_security:
+            try:
+                data = await apply_coroutine(ISecurityInfo(ob))
+            except TypeError:
+                self.response.write(f"Could not index {ob}")
+                return
         else:
             data = {
                 # always need these...
@@ -407,11 +379,6 @@ class Migrator:
         self.indexed += 1
         self.batch[ob.uuid] = {"action": batch_type, "data": data}
 
-        if self.lookup_index:
-            im = find_index_manager(ob)
-            if im:
-                self.batch[ob.uuid]["__index__"] = await im.get_index_name()
-
         if self.log_details:
             self.response.write(
                 f"({self.processed} {int(self.per_sec())}) "
@@ -474,9 +441,7 @@ class Migrator:
             bulk_data.append({payload["action"]: action_data})
             if payload["action"] != "delete":
                 bulk_data.append(data)
-        results = await self.conn.bulk(
-            index=self.work_index_name, doc_type=DOC_TYPE, body=bulk_data
-        )
+        results = await self.conn.bulk(index=self.work_index_name, body=bulk_data)
         if results["errors"]:
             errors = []
             for result in results["items"]:
@@ -524,7 +489,7 @@ class Migrator:
                     await self.attempt_flush()
                     # no longer present on db, this was orphaned
                     self.orphaned.append(uuid)
-                except aioelasticsearch.exceptions.NotFoundError:
+                except elasticsearch.exceptions.NotFoundError:
                     # it was deleted in the meantime so we're actually okay
                     self.orphaned.append(uuid)
             else:
@@ -546,12 +511,8 @@ class Migrator:
             self.response.write("Next index disabled")
         if self.active_task_id is not None:
             self.response.write("Canceling copy of index task")
-            conn_es = await self.conn.transport.get_connection()
-            async with conn_es.session.post(
-                join(str(conn_es.base_url), "_tasks", self.active_task_id, "_cancel"),
-                headers={"Content-Type": "application/json"},
-            ):
-                await asyncio.sleep(5)
+            await self.conn.tasks.cancel(self.active_task_id)
+            await asyncio.sleep(5)
         if self.work_index_name:
             self.response.write("Deleting new index")
             await self.conn.indices.delete(self.work_index_name)
@@ -649,24 +610,3 @@ class Migrator:
             self.response.write("Old index deleted")
         except elasticsearch.exceptions.NotFoundError:
             pass
-
-        if len(self.sub_indexes) > 0:
-            self.response.write(f"Migrating sub indexes: {len(self.sub_indexes)}")
-            for ob in self.sub_indexes:
-                im = get_adapter(ob, IIndexManager)
-                migrator = Migrator(
-                    self.utility,
-                    ob,
-                    response=self.response,
-                    force=self.force,
-                    log_details=self.log_details,
-                    memory_tracking=self.memory_tracking,
-                    bulk_size=self.bulk_size,
-                    full=self.full,
-                    reindex_security=self.reindex_security,
-                    mapping_only=self.mapping_only,
-                    index_manager=im,
-                    children_only=True,
-                )
-                self.response.write(f"Migrating index for: {ob}")
-                await migrator.run_migration()
